@@ -1,8 +1,3 @@
-# Author: Oscar Perpinan Lamigueiro oscar.perpinan@upm.es
-# Date :  June 2011
-# Version 0.10
-# Licence GPL v3
-
 ##xyplot for directions created with xyLayer
 setGeneric('xyplot')
 
@@ -35,10 +30,7 @@ setMethod('xyplot', signature(x='formula', data='Raster'),
             yscale.components=yscale.raster,
             par.settings=rasterTheme(),...){
 
-            ## names replace layerNames with raster version 2.0-04
-            rasterVersion <- as.character(packageVersion('raster'))
-            nms <- if (compareVersion(rasterVersion, '2.0-04') == -1) layerNames(data) else names(data)
-
+            nms <- names(data)
             nl <- nlayers(data)
 
             data <- sampleRegular(data, maxpixels, asRaster=TRUE)
